@@ -5,7 +5,7 @@ import jax
 import jax.numpy as jnp
 from absl.testing import absltest, parameterized
 
-import blackjax.inference.hmc.integrators as integrators
+import blackjax.mcmc.integrators as integrators
 
 
 def HarmonicOscillator(inv_mass_matrix, k=1.0, m=1.0):
@@ -42,7 +42,7 @@ def PlanetaryMotion(inv_mass_matrix):
 
     def kinetic_energy(p):
         z = jnp.stack([p["x"], p["y"]], axis=-1)
-        return 0.5 * jnp.dot(inv_mass_matrix, z ** 2)
+        return 0.5 * jnp.dot(inv_mass_matrix, z**2)
 
     return potential_energy, kinetic_energy
 
@@ -102,16 +102,23 @@ class IntegratorTest(chex.TestCase):
         itertools.product(
             ["free_fall", "harmonic_oscillator", "planetary_motion"],
             ["velocity_verlet", "mclachlan", "yoshida"],
+            ["default_gradient", "forward_gradients"],
         )
     )
-    def test_integrator(self, example_name, integrator_name):
+    def test_integrator(self, example_name, integrator_name, gradient_type):
         integrator = algorithms[integrator_name]
         example = examples[example_name]
 
         model = example["model"]
         potential, kinetic_energy = model(example["inv_mass_matrix"])
 
-        step = self.variant(integrator["algorithm"](potential, kinetic_energy))
+        if gradient_type == "default_gradient":
+            step = self.variant(integrator["algorithm"](potential, kinetic_energy))
+        elif gradient_type == "forward_gradients":
+            potential_grad = jax.jacfwd(potential)
+            step = self.variant(
+                integrator["algorithm"](potential, kinetic_energy, potential_grad)
+            )
 
         step_size = example["step_size"]
 
